# -*- coding: utf-8 -*-
"""
Chordix
=======
The main function of Chordix is incomplete now.

Provides
--------
1. ...

- As midi file regard C4 as 60, so in Chordix, we consider C4's pitch space as 60 instead of 0.

To import `Chordix`::

  >>> import Chordix

To search for documents containing a keyword, do::

  >>> Chordix.lookfor('keyword')

Available subpackages
---------------------
...

Some naming regulations:
------------------------
...
"""

# no need to compatible with python2
from __future__ import annotations

from typing import Literal

try:
    ...
except ImportError:
    ...


def lookfor(what: str) -> None:
    """
    Search docstrings for occurrences of a given word or phrase.
    Prints results to stdout.
    """
    return None



import setuptools


VERSION = "0.0.10"
DESCRIPTION = f"""
Chordix uses harmony theories to analyse chords, chord progressions and midi music segments.
"""


setuptools.setup(
    name="Chordix",
    version=VERSION,
    author="Jason Lee",
    author_email="2593292614@qq.com",
    description=DESCRIPTION,
    long_description=open('README.md', 'r', encoding="utf-8").read(),
    long_description_content_type='text/markdown',
    install_package_data=True,
    package_data={'': ['*.txt', '*.md', '*.json', '*.png']},
    url="https://github.com/JasonLee-p/Chordix",
    install_requires=[
        'numpy==1.21.2',
    ],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)",
        "Operating System :: OS Independent",
    ],
)
